@@ -50,25 +50,13 @@ void unmark_all_pages_callback(GtkWidget *widget, gpointer data)
         if((!GTK_GS(ggv->gs)->loaded) || (!GTK_GS(ggv->gs)->structured_doc))
                 return;
 
-        n = gtk_gs_document_numpages (GTK_GS (ggv->gs));
+        n = gtk_gs_get_page_count (GTK_GS (ggv->gs));
         gtk_clist_freeze(GTK_CLIST(ggv->pagelist));
         for (i = 0; i < n; i++)
                 gtk_check_list_set_toggled (GTK_CHECK_LIST (ggv->pagelist), i, FALSE);
         gtk_clist_thaw(GTK_CLIST(ggv->pagelist));
 }
 
-void toggle_current_page_callback(GtkWidget *widget, gpointer data) 
-{
-        ggv_window *ggv = (ggv_window *) data;
-
-        g_return_if_fail (ggv!=NULL);
-        if((!GTK_GS(ggv->gs)->loaded) || (!GTK_GS(ggv->gs)->structured_doc))
-                return;
-
-        gtk_check_list_toggle_row (GTK_CHECK_LIST (ggv->pagelist),
-                                   GTK_GS (ggv->gs)->current_page);
-}
-
 void toggle_even_pages_callback(GtkWidget *widget, gpointer data) 
 {
         gint i, n;
@@ -79,7 +67,7 @@ void toggle_even_pages_callback(GtkWidget *widget, gpointer data)
         if((!GTK_GS(ggv->gs)->loaded) || (!GTK_GS(ggv->gs)->structured_doc))
                 return;
 
-        n = gtk_gs_document_numpages (GTK_GS (ggv->gs));
+        n = gtk_gs_get_page_count (GTK_GS (ggv->gs));
         gtk_clist_freeze(GTK_CLIST(ggv->pagelist));
         for (i = 1; i < n; i += 2) {
                 checked = gtk_check_list_get_toggled(GTK_CHECK_LIST (ggv->pagelist), i);
@@ -98,7 +86,7 @@ void toggle_odd_pages_callback(GtkWidget *widget, gpointer data)
         if((!GTK_GS(ggv->gs)->loaded) || (!GTK_GS(ggv->gs)->structured_doc))
                 return;
 
-        n = gtk_gs_document_numpages (GTK_GS (ggv->gs));
+        n = gtk_gs_get_page_count (GTK_GS (ggv->gs));
         gtk_clist_freeze(GTK_CLIST(ggv->pagelist));
         for (i = 0; i < n; i += 2) {
                 checked = gtk_check_list_get_toggled(GTK_CHECK_LIST (ggv->pagelist), i);
@@ -117,7 +105,7 @@ void toggle_all_pages_callback(GtkWidget *widget, gpointer data)
         if((!GTK_GS(ggv->gs)->loaded) || (!GTK_GS(ggv->gs)->structured_doc))
                 return;
 
-        n = gtk_gs_document_numpages (GTK_GS (ggv->gs));
+        n = gtk_gs_get_page_count (GTK_GS (ggv->gs));
         gtk_clist_freeze(GTK_CLIST(ggv->pagelist));
         for (i = 0; i < n; i++) {
                 checked = gtk_check_list_get_toggled(GTK_CHECK_LIST (ggv->pagelist), i);
@@ -126,6 +114,18 @@ void toggle_all_pages_callback(GtkWidget *widget, gpointer data)
         gtk_clist_thaw(GTK_CLIST(ggv->pagelist));
 }
 
+void toggle_current_page_callback(GtkWidget *widget, gpointer data) 
+{
+        ggv_window *ggv = (ggv_window *) data;
+
+        g_return_if_fail (ggv!=NULL);
+        if((!GTK_GS(ggv->gs)->loaded) || (!GTK_GS(ggv->gs)->structured_doc))
+                return;
+
+        gtk_check_list_toggle_row (GTK_CHECK_LIST (ggv->pagelist),
+                                   GTK_GS (ggv->gs)->current_page);
+}
+
 static void about_destroy_callback(GtkObject *obj, GtkWidget **about)
 {
 	*about = NULL;
@@ -177,7 +177,7 @@ void about_callback(GtkWidget *widget, gpointer data)
 				(const gchar **) authors,
 				_("PostScript(TM) document viewer.\n"
                                   "Based on Tim Theisen's excellent Ghostview application."),
-				"ggv-splash.png");
+				"ggv/ggv-splash.png");
         gtk_signal_connect(GTK_OBJECT(about), "destroy",
                            GTK_SIGNAL_FUNC(about_destroy_callback), &about);
 
@@ -192,11 +192,15 @@ void new_callback(GtkWidget *widget, gpointer data)
 }
 
 void button_press_callback(GtkWidget *widget, GdkEventButton *event,
-                           gpointer data)
+				  gpointer data)
 {
         ggv_window *ggv = (ggv_window *)data;
         gint button = event->button;
+        gint x = 0;
+        gint y = 0;
 
+        x += event->x;
+        y += event->y;
         switch(button) {
         case 1: {
                 if(!ggv->pan) {
@@ -217,7 +221,7 @@ void button_press_callback(GtkWidget *widget, GdkEventButton *event,
                         ggv->prev_y = wy;
                 }
                 break;
-        }
+	}
         case 2: {
                 gfloat cx, cy;
                 gint x = 0, y = 0;
@@ -320,8 +324,7 @@ gint exit_callback(GtkWidget *widget, gpointer data)
                                      &ggv_default_height);
 
                 g_list_free(node);
-                gtk_widget_destroy (GTK_WIDGET (ggv->main_window));
-                g_free(ggv);
+                close_window(ggv);
         }
 
 	gtk_main_quit ();
@@ -356,10 +359,10 @@ void file_open_ok_callback(GtkWidget *widget, gpointer data)
         ggv_window *ggv = (ggv_window *)data;
         gchar *file;
         gchar *base_filename;
-        char *error_msg;
         struct stat stat_rec;
 
         save_window_size(ggv->file_sel, &file_sel_width, &file_sel_height);
+
 	file = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(ggv->file_sel)));
 
         /* We have to verify that this file exists */
@@ -410,16 +413,7 @@ watch_file_callback(GtkWidget *widget, gpointer data)
         GtkGS *gs;
         gs = GTK_GS(ggv->gs);
         
-        gs->watch_doc = GTK_CHECK_MENU_ITEM(widget)->active;
-
-	if(!gs->watch_doc) {
-		if(gs->timer_tag)
-                        gtk_timeout_remove(gs->timer_tag);
-	}
-        else {
-		gs->timer_tag = gtk_timeout_add(GGV_WATCH_INTERVAL,
-						 timer_callback, ggv);
-        }
+        gtk_gs_set_watch_file(gs, GTK_CHECK_MENU_ITEM(widget)->active);
 }
 
 void
@@ -430,29 +424,18 @@ antialiasing_callback(GtkWidget *widget, gpointer data)
         GtkGS *gs;
         gs = GTK_GS(ggv->gs);
         
-        gs->antialiased = GTK_CHECK_MENU_ITEM(widget)->active;
-
-        /* We assume that if it gets here is because it was toggled,
-           so no need to check what is the previous state of gs->antialiased */
-
-        reload_callback(NULL, ggv);
-
+        gtk_gs_set_antialiasing(gs, GTK_CHECK_MENU_ITEM(widget)->active);
 }
 
 void
 override_paper_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *) data;
-        
         GtkGS *gs;
+
         gs = GTK_GS(ggv->gs);
-        
-        gs->override_media = GTK_CHECK_MENU_ITEM(widget)->active;
-
-        gtk_gs_set_pagemedia(gs, -1, gs->current_page);
-
-        if (GTK_GS(ggv->gs)->loaded)
-                gtk_gs_goto_page (GTK_GS(ggv->gs), GTK_GS(ggv->gs)->current_page);
+        gtk_gs_set_override_media (gs, GTK_CHECK_MENU_ITEM(widget)->active);
+        synchronize_paper_items(ggv);
 }
 
 void
@@ -463,15 +446,8 @@ override_orientation_callback(GtkWidget *widget, gpointer data)
         GtkGS *gs;
         gs = GTK_GS(ggv->gs);
         
-        g_print("Overriding orientation GS [%d]\n", GTK_CHECK_MENU_ITEM(widget)->active);
-
         gtk_gs_set_override_orientation (gs, GTK_CHECK_MENU_ITEM(widget)->active);
-
-        /* We assume that if it gets here is because it was toggled,
-           so no need to check what is the previous state of gs->antialiased */
-
-        if (GTK_GS(ggv->gs)->loaded)
-                gtk_gs_goto_page (GTK_GS(ggv->gs), GTK_GS(ggv->gs)->current_page);
+        synchronize_orientation_items(ggv);
 }
 
 void orientation_callback(GtkWidget *widget, gpointer data)
@@ -484,13 +460,7 @@ void orientation_callback(GtkWidget *widget, gpointer data)
                 return;
         }
 
-        /* Set the new orientation */
-        g_print("Setting fallback orientation GS [%d]\n",GPOINTER_TO_INT(wwd->data));
-      
-        gtk_gs_set_orientation (GTK_GS(ggv->gs), GPOINTER_TO_INT(wwd->data));
-
-        if (GTK_GS(ggv->gs)->loaded)
-                gtk_gs_goto_page (GTK_GS(ggv->gs), GTK_GS(ggv->gs)->current_page);
+        gtk_gs_set_default_orientation (GTK_GS(ggv->gs), GPOINTER_TO_INT(wwd->data));
 }
 
 
@@ -570,17 +540,18 @@ void motion_callback(GtkWidget *widget, GdkEventMotion *event,
         ggv_window *ggv = (ggv_window *) data;
 
         if(ggv->pan) {
-                gtk_gs_scroll(GTK_GS(ggv->gs), -event->x + ggv->prev_x, -event->y + ggv->prev_y);;
+                gtk_gs_scroll(GTK_GS(ggv->gs), -event->x + ggv->prev_x,
+                              -event->y + ggv->prev_y);;
                 ggv->prev_x = event->x;
                 ggv->prev_y = event->y;
         }
         else {
-#if 0
-                mouse_moved (ggv->cd, ggv->gs->window, 
-                             event->x, event->y,
-                             ggv->main_window->allocation.width,
-                             ggv->main_window->allocation.height);
-#endif
+                GtkGS *gs = GTK_GS(ggv->gs);
+                if(event->window == gs->pstarget && gs->doc != NULL) {
+                        ggv->xcoord = event->x/gs->xdpi/gs->zoom_factor;
+                        ggv->ycoord = event->y/gs->ydpi/gs->zoom_factor;
+                        refresh_coordinates(ggv);
+               }
         }
 }
 
@@ -606,42 +577,31 @@ void key_pressed_event_callback(GtkWidget *widget, GdkEventKey *event,
                 case GTK_GS_ORIENTATION_PORTRAIT:
                         if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane), 
                                                  GTK_SCROLLPANE_SCROLL_DOWN, TRUE)) {
+                                /* Since we are doing wrapping, go to top of the page */
+                                gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
+                                                         GTK_SCROLLPANE_GOTOEDGE_LOWER, 
+                                                         GTK_SCROLLPANE_GOTOEDGE_LOWER);
+                                /* g_print("Scroll Return false\n"); */
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page + 1);
-                                if(ggv->pane_auto_jump)
-                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
-                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER, 
-                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER);
                         }
                         break;
                 case GTK_GS_ORIENTATION_LANDSCAPE:
                         if (!gtk_scrollpane_step (GTK_SCROLLPANE (ggv->scrollpane),
-                                                  GTK_SCROLLPANE_SCROLL_LEFT,TRUE)) {
-  				goto_page( ggv, GTK_GS(ggv->gs)->current_page + 1);
-                                if(ggv->pane_auto_jump)
-                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
-                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER, 
-                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER);
-                         }
+                                                       GTK_SCROLLPANE_SCROLL_LEFT,TRUE)) {
+				goto_page( ggv, GTK_GS(ggv->gs)->current_page + 1);
+                        }
                         break;
                 case GTK_GS_ORIENTATION_SEASCAPE:
                         if (!gtk_scrollpane_step (GTK_SCROLLPANE (ggv->scrollpane),
                                                   GTK_SCROLLPANE_SCROLL_RIGHT,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page + 1);
-                                if(ggv->pane_auto_jump)
-                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
-                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER, 
-                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER);
-                         }
+                        }
                         break;
                 case GTK_GS_ORIENTATION_UPSIDEDOWN:
                         if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),
-                                                 GTK_SCROLLPANE_SCROLL_UP,TRUE)) {
+                                                     GTK_SCROLLPANE_SCROLL_UP,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page + 1);
-                                if(ggv->pane_auto_jump)
-                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
-                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER, 
-                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER);
-                         }
+                        }
                         break;
                 }
                 break;
@@ -652,41 +612,22 @@ void key_pressed_event_callback(GtkWidget *widget, GdkEventKey *event,
                         if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),
                                                  GTK_SCROLLPANE_SCROLL_UP,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page - 1);
-                                if(ggv->pane_auto_jump)
-                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
-                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER, 
-                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER);
-                         }
+                        }
                         break;
                 case GTK_GS_ORIENTATION_LANDSCAPE:
-                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),
-                                                 GTK_SCROLLPANE_SCROLL_RIGHT,TRUE)) {
+                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),GTK_SCROLLPANE_SCROLL_RIGHT,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page - 1);
-                                if(ggv->pane_auto_jump)
-                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
-                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER, 
-                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER);
-                         }
+                        }
                         break;
                 case GTK_GS_ORIENTATION_SEASCAPE:
-                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),
-                                                 GTK_SCROLLPANE_SCROLL_LEFT,TRUE)) {
+                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),GTK_SCROLLPANE_SCROLL_LEFT,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page - 1);
-                                if(ggv->pane_auto_jump)
-                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
-                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER, 
-                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER);
-                         }
+                        }
                         break;
                 case GTK_GS_ORIENTATION_UPSIDEDOWN:
-                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),
-                                                 GTK_SCROLLPANE_SCROLL_DOWN,TRUE)) {
+                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),GTK_SCROLLPANE_SCROLL_DOWN,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page - 1);
-                                if(ggv->pane_auto_jump)
-                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
-                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER, 
-                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER);
-                         }
+                        }
                         break;
                 }
                 break;
@@ -743,7 +684,7 @@ void last_page_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *) data;
         if (GTK_GS(ggv->gs)->loaded)
-	        goto_page(ggv, GTK_GS(ggv->gs)->doc->numpages - 1);
+	        goto_page(ggv, gtk_gs_get_page_count(GTK_GS(ggv->gs)) - 1);
 }
 
 void next_page_callback(GtkWidget *widget, gpointer data)
@@ -764,16 +705,16 @@ void previous_page_callback(GtkWidget *widget, gpointer data)
 void open_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *)data;
-        gchar *dirname = NULL;
+        gchar *dirname;
 
         if(ggv->file_sel)
                 return;
 
 	ggv->file_sel = gtk_file_selection_new(_("GGv: Open File"));
         gtk_window_set_default_size(GTK_WINDOW(ggv->file_sel), file_sel_width,
-                                               file_sel_height);
+                                    file_sel_height);
         gtk_window_set_position(GTK_WINDOW(ggv->file_sel), GTK_WIN_POS_MOUSE);
-	gtk_signal_connect(GTK_OBJECT(ggv->file_sel), "delete_event",
+        gtk_signal_connect(GTK_OBJECT(ggv->file_sel), "delete_event",
 			   GTK_SIGNAL_FUNC(file_open_delete_callback), data);
 	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(ggv->file_sel)->cancel_button),
 			   "clicked",
@@ -790,9 +731,8 @@ void open_callback(GtkWidget *widget, gpointer data)
             (strcmp(dirname, ".") != 0)) {
                 gtk_file_selection_complete(GTK_FILE_SELECTION(ggv->file_sel),
                                                     dirname);
-	}
-        if(dirname)
 		g_free (dirname);
+	}
         gtk_widget_show(ggv->file_sel);
 }
 
@@ -830,7 +770,7 @@ void print_marked_pages_callback(GtkWidget *widget, gpointer data)
 
         if(GTK_GS(ggv->gs)->loaded) {
                 if(gtk_gs_count_marked_pages(GTK_GS(ggv->gs)) == 0) {
-			GtkWidget *dialog, *label;
+			GtkWidget *dialog;
          		int button;
 
         		dialog = gnome_message_box_new (
@@ -908,13 +848,13 @@ void file_save_delete_callback(GtkWidget *widget, GdkEventAny *e,
 
 void file_save_ok_callback(GtkWidget *widget, gpointer data)
 {
-        gchar *base_filename, *flash;
-        char *error_msg;
+        gchar *base_filename;
         struct stat stat_rec;
         ggv_window *ggv = (ggv_window *)data;
         gchar *file;
 
-        save_window_size(ggv->save_file_sel, &file_sel_width, &file_sel_height);
+        save_window_size(ggv->file_sel, &file_sel_width, &file_sel_height);
+
 	file = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(ggv->save_file_sel)));
 
         if(stat(file,&stat_rec) == 0) {
@@ -1034,7 +974,6 @@ void select_page_callback(GtkWidget *widget, gint row, gint column,
 
         g_return_if_fail(widget != NULL);
 
-
         /* If event is null then it is not from the user */
         if (event == NULL || event->button == 1) {
                 if(GTK_GS(ggv->gs)->current_page != row) {
@@ -1081,8 +1020,15 @@ void paper_callback(GtkWidget *widget, gpointer *data)
                 return;
         }
 
-        gs->default_page_media = GPOINTER_TO_INT(wwd->data);
-        gtk_gs_set_pagemedia(gs, -1, gs->current_page);
+        gs->default_media = GPOINTER_TO_INT(wwd->data);
+        gtk_gs_set_page_media(gs, -1, gs->current_page);
+}
+
+void zoom_to_fit_callback(GtkWidget *widget, gpointer data)
+{
+        ggv_window *ggv = (ggv_window *)data;
+
+        gtk_gs_zoom_to_fit(GTK_GS(ggv->gs));
 }
 
 void zoom_callback(GtkWidget *widget, gpointer data)
@@ -1103,7 +1049,7 @@ void zoom_callback(GtkWidget *widget, gpointer data)
         zoom_to(ggv, new_mag);
 }
 
-void zoomin_callback(GtkWidget *widget, gpointer *data)
+void zoomin_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *)data;
 
@@ -1119,7 +1065,7 @@ void zoomin_callback(GtkWidget *widget, gpointer *data)
 }
 
 
-void zoomout_callback(GtkWidget *widget, gpointer *data)
+void zoomout_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *)data;
 
@@ -1137,36 +1083,32 @@ void zoomout_callback(GtkWidget *widget, gpointer *data)
 
 void prefs_destroy_callback(GtkWidget *w, ggv_prefs *p)
 {
+        g_free(p->media_choice);
+        p->media_choice = NULL;
         p->pbox = NULL;
 }
 
 void prefs_apply_callback(GtkWidget *w, gint page, ggv_prefs *p)
 {
         GtkWidget *active;
-        gint i;
+        gint i, n;
 
         if( page != -1 ) return;
 
-        if(gs_cmd)
-                g_free(gs_cmd);
-        gs_cmd = g_strdup(gtk_entry_get_text(GTK_ENTRY(p->gs)));
-        if(gs_scan_pdf_cmd)
-                g_free(gs_scan_pdf_cmd);
-        gs_scan_pdf_cmd = g_strdup(gtk_entry_get_text(GTK_ENTRY(p->scan_pdf)));
-        if (gs_ungzip_cmd)
-                g_free (gs_ungzip_cmd);
-        gs_ungzip_cmd = g_strdup (gtk_entry_get_text (GTK_ENTRY (p->unzip)));
-        if (gs_unbzip2_cmd)
-		g_free (gs_unbzip2_cmd);
-        gs_unbzip2_cmd = g_strdup (gtk_entry_get_text (GTK_ENTRY (p->unbzip2)));
+        gtk_gs_defaults_set_interpreter_cmd(gtk_entry_get_text(GTK_ENTRY(p->gs)));
+        gtk_gs_defaults_set_scan_pdf_cmd(gtk_entry_get_text(GTK_ENTRY(p->scan_pdf)));
+        gtk_gs_defaults_set_ungzip_cmd(gtk_entry_get_text (GTK_ENTRY (p->unzip)));
+        gtk_gs_defaults_set_unbzip2_cmd(gtk_entry_get_text (GTK_ENTRY (p->unbzip2)));
+
         if(gs_print_cmd)
                 g_free(gs_print_cmd);
         gs_print_cmd = g_strdup(gtk_entry_get_text(GTK_ENTRY(p->print)));
 
         active = gtk_menu_get_active(GTK_MENU(gtk_option_menu_get_menu(GTK_OPTION_MENU(p->media))));
-        for(i = 0; i < PAPER_SIZE_COUNT; i++)
+        n = gtk_gs_defaults_get_paper_count();
+        for(i = 0; i < n; i++)
                 if(active == p->media_choice[i]) {
-                        gtk_gs_set_default_page_media(i);
+                        gtk_gs_defaults_set_media(i);
                         break;
                 }
 
@@ -1174,7 +1116,7 @@ void prefs_apply_callback(GtkWidget *w, gint page, ggv_prefs *p)
         for(i = 0; i < MENU_ZOOM_SIZE - 1; i++){
                 if(active == p->zoom_choice[i]) {
                         gs_default_magnification = ZoomMenuMagnificationSteps[i];
-                        gtk_gs_set_default_zoom_factor(ggv_compute_zoom(gs_default_magnification));
+                        gtk_gs_defaults_set_zoom_factor(compute_zoom(gs_default_magnification));
                         break;
                 }
         }
@@ -1182,16 +1124,24 @@ void prefs_apply_callback(GtkWidget *w, gint page, ggv_prefs *p)
         active = gtk_menu_get_active(GTK_MENU(gtk_option_menu_get_menu(GTK_OPTION_MENU(p->orientation))));
         for(i = 0; i < MENU_ORIENTATION_SIZE; i++){
                 if(active == p->orientation_choice[i]) {
-                        gtk_gs_set_default_orientation(i);
+                        gtk_gs_defaults_set_orientation(i);
                         break;
                 }
         }
 
-        gtk_gs_set_default_respect_eof(GTK_TOGGLE_BUTTON(p->respect_eof)->active);
-        gtk_gs_set_default_watch_doc(GTK_TOGGLE_BUTTON(p->watch)->active);
-        gtk_gs_set_default_antialiased(GTK_TOGGLE_BUTTON(p->aa)->active);
-        gtk_gs_set_default_override_media(GTK_TOGGLE_BUTTON(p->override_media)->active);
-        gtk_gs_set_default_override_orientation(GTK_TOGGLE_BUTTON(p->override_orientation)->active);
+        active = gtk_menu_get_active(GTK_MENU(gtk_option_menu_get_menu(GTK_OPTION_MENU(p->units))));
+        for(i = 0; i < MENU_UNITS_SIZE; i++){
+                if(active == p->unit_choice[i]) {
+                        ggv_unit_index = i;
+                        break;
+                }
+        }
+
+        gtk_gs_defaults_set_respect_eof(GTK_TOGGLE_BUTTON(p->respect_eof)->active);
+        gtk_gs_defaults_set_watch_doc(GTK_TOGGLE_BUTTON(p->watch)->active);
+        gtk_gs_defaults_set_antialiased(GTK_TOGGLE_BUTTON(p->aa)->active);
+        gtk_gs_defaults_set_override_media(GTK_TOGGLE_BUTTON(p->override_media)->active);
+        gtk_gs_defaults_set_override_orientation(GTK_TOGGLE_BUTTON(p->override_orientation)->active);
 
         gs_panel = GTK_TOGGLE_BUTTON(p->tbar)->active;
         gs_save_geometry = GTK_TOGGLE_BUTTON(p->savegeo)->active;
@@ -1222,29 +1172,3 @@ void prefs_changed_callback(GtkWidget *w, ggv_prefs *p)
 {
 	gnome_property_box_changed(p->pbox);
 }
-
-/* Reload file if it was changed */
-gint timer_callback (gpointer data)
-{
-	ggv_window *ggv;
-        GtkGS *gs;
-	struct stat sbuf;
-
-        g_assert (data);
-
-	ggv = (ggv_window *) data;
-        gs = GTK_GS (ggv->gs);
-
-        /* remove timer if no valid file is loaded */
-	if (!GTK_GS(ggv->gs)->loaded || !ggv->gs || !gs->watch_doc || !gs->gs_psfile) {
-                gs->timer_tag = 0;
-		return FALSE;
-	}
-
-	if (!gs->busy && !stat(gs->gs_filename, &sbuf) &&
-	    (sbuf.st_mtime != gs->mtime) &&
-	    (time (NULL) - sbuf.st_mtime >= GGV_WATCH_TIMEOUT))
-		reload_callback (NULL, ggv);
-
-        return TRUE;
-}
