@@ -51,8 +51,9 @@ void prefs_apply_callback(GtkWidget *w, gint page, ggv_prefs *p);
 void prefs_help_callback(GtkWidget *w, gint page, ggv_prefs *p);
 void prefs_changed_callback(GtkWidget *w, ggv_prefs *p);
 void zoom_to(ggv_window *ggv, gint magstep);
-void zoomin_callback(GtkWidget *widget, gpointer *data);
-void zoomout_callback(GtkWidget *widget, gpointer *data);
+void zoomin_callback(GtkWidget *widget, gpointer data);
+void zoomout_callback(GtkWidget *widget, gpointer data);
+void zoom_to_fit_callback(GtkWidget *widget, gpointer data);
 void recent_add(char *filename);
 void recent_update_menus (ggv_window *ggv, GList *recent_files);
 void recent_update(void);
