@@ -1,10 +1,9 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 
-#ifndef __GGV_MISC_H_H__
-#define __GGV_MISC_H__
+#ifndef __GGV_UTILS_H__
+#define __GGV_UTILS_H__
 
 #include <gnome.h>
-#include <math.h>
 
 /* Quote filename for system call */
 gchar *ggv_quote_filename (const gchar *str);
@@ -27,6 +26,4 @@ void ggv_set_tooltip(GtkWidget* w, const gchar* tip);
 
 void ggv_stock_init (void);
 
-gfloat ggv_compute_zoom(gint zoom_spec);
-
 #endif
