@@ -12,7 +12,6 @@
 #include <gtk/gtkwidget.h>
 #include <errno.h>
 #include <signal.h>
-#include "ps.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -24,20 +23,18 @@ extern "C" {
 
 #define MAX_BUFSIZE 1024
 
-#define GGV_WATCH_INTERVAL 1000
-#define GGV_WATCH_TIMEOUT  2
+typedef struct _GtkGS          GtkGS;
+typedef struct _GtkGSClass     GtkGSClass;
+typedef struct _GtkGSPaperSize GtkGSPaperSize;
 
-typedef struct _GtkGS      GtkGS;
-typedef struct _GtkGSClass GtkGSClass;
-
-enum
+typedef enum
 {
         GTK_GS_ORIENTATION_NONE = -1,
         GTK_GS_ORIENTATION_PORTRAIT = 0,
         GTK_GS_ORIENTATION_SEASCAPE = 3,
         GTK_GS_ORIENTATION_UPSIDEDOWN = 2,
         GTK_GS_ORIENTATION_LANDSCAPE = 1,
-};
+} GtkGSOrientation;
 
 struct _GtkGS
 {
@@ -101,7 +98,7 @@ struct _GtkGS
 	gboolean    watch_doc;                /* Automatic reload if file changed */
         gboolean    antialiased;              /* Using antialiased display */
         gboolean    respect_eof;              /* respect EOF comments? */
-        gint        default_page_media;
+        gint        default_media;
         gboolean    override_media;
         gfloat      xdpi, ydpi;
         gboolean    override_orientation;
@@ -135,6 +132,12 @@ struct record_list
         struct record_list *next;
 };
 
+struct _GtkGSPaperSize
+{
+        gchar *name;
+        gint width, height;
+};
+
 guint      gtk_gs_get_type (void);
 
 GtkWidget *gtk_gs_new_from_file(GtkAdjustment *hadj, GtkAdjustment *vadj, gchar *fname);
@@ -142,39 +145,72 @@ GtkWidget *gtk_gs_new(GtkAdjustment *hadj, GtkAdjustment *vadj);
 gboolean   gtk_gs_load (GtkGS *gs, const gchar *fname);
 
 /* control functions */
-void         gtk_gs_center_page(GtkGS *gs);
-void         gtk_gs_scroll(GtkGS *gs, gint, gint);
-void         gtk_gs_set_center(GtkGS *gs, gfloat x, gfloat y);
+void         gtk_gs_center_page (GtkGS *gs);
+void         gtk_gs_scroll (GtkGS *gs, gint, gint);
 gboolean     gtk_gs_next_page(GtkGS *gs);
 gboolean     gtk_gs_prev_page(GtkGS *gs);
 gboolean     gtk_gs_goto_page(GtkGS *gs, gint);
-gboolean     gtk_gs_set_pagemedia(GtkGS *gs, gint new_pagemedia, gint pageid);
-gboolean     gtk_gs_set_orientation(GtkGS *gs, gint orientation);
-void         gtk_gs_set_zoom(GtkGS *gs, gfloat zoom);
 gint         gtk_gs_enable_interpreter(GtkGS *gs);
 void         gtk_gs_disable_interpreter(GtkGS *gs);
+
+gint         gtk_gs_get_current_page(GtkGS *gs);
+gint         gtk_gs_get_page_count(GtkGS *gs);
+gboolean     gtk_gs_set_page_media(GtkGS *gs, gint new_pagemedia, gint pageid);
+gboolean     gtk_gs_set_default_orientation(GtkGS *gs, gint orientation);
+gint         gtk_gs_get_default_orientation(GtkGS *gs);
+void         gtk_gs_set_default_media(GtkGS *gs, gint media);
+gint         gtk_gs_get_default_media(GtkGS *gs);
+void         gtk_gs_set_zoom(GtkGS *gs, gfloat zoom);
+gfloat       gtk_gs_get_zoom(GtkGS *gs);
+void         gtk_gs_zoom_to_fit(GtkGS *gs);
+void         gtk_gs_set_center(GtkGS *gs, gfloat hval, gfloat vval);
 gint         gtk_gs_get_orientation(GtkGS *gs);
-const gchar *gtk_gs_document_title(GtkGS *widget);
-guint        gtk_gs_document_numpages(GtkGS *widget);
-const gchar *gtk_gs_document_page_label(GtkGS *widget, int page);
+void         gtk_gs_set_override_orientation(GtkGS *gs, gboolean f);
+gboolean     gtk_gs_get_override_orientation(GtkGS *gs);
+void         gtk_gs_set_respect_eof(GtkGS *gs, gboolean f);
+gboolean     gtk_gs_get_respect_eof(GtkGS *gs);
+void         gtk_gs_set_antialiasing(GtkGS *gs, gboolean f);
+gboolean     gtk_gs_get_antialiasing(GtkGS *gs);
+void         gtk_gs_set_watch_file(GtkGS *gs, gboolean f);
+gboolean     gtk_gs_get_watch_file(GtkGS *gs);
+void         gtk_gs_set_override_media(GtkGS *gs, gboolean f);
+gboolean     gtk_gs_get_override_media(GtkGS *gs);
+const gchar *gtk_gs_get_document_title(GtkGS *widget);
+guint        gtk_gs_get_document_numpages(GtkGS *widget);
+const gchar *gtk_gs_get_document_page_label(GtkGS *widget, int page);
 gint         gtk_gs_count_marked_pages(GtkGS *widget);
 
 /* defaults accessors */
-void     gtk_gs_set_default_page_media(gint iNewPageMedia); 
-void     gtk_gs_set_default_override_media(gboolean bOverMedia);
-void     gtk_gs_set_default_antialiased(gint iNewAntialiased);
-void     gtk_gs_set_default_orientation(gint);
-void     gtk_gs_set_default_override_orientation(gboolean bOverOrien);
-void     gtk_gs_set_default_watch_doc(gint iNewWatchDoc);
-gint     gtk_gs_get_default_page_media();
-gboolean gtk_gs_get_default_override_media();
-gboolean gtk_gs_get_default_antialiased();
-gint     gtk_gs_get_default_orientation();
-gboolean gtk_gs_get_default_override_orientation();
-void     gtk_gs_set_default_zoom_factor(gfloat fZoom);
-gfloat   gtk_gs_get_default_zoom_factor();
-gint     gtk_gs_get_default_watch_doc() ;
-void     gtk_gs_set_override_orientation (GtkGS *gs, gboolean bNewOverride);
+void     gtk_gs_defaults_set_media(gint iNewPageMedia); 
+void     gtk_gs_defaults_set_override_media(gboolean bOverMedia);
+void     gtk_gs_defaults_set_antialiased(gint iNewAntialiased);
+void     gtk_gs_defaults_set_orientation(gint);
+void     gtk_gs_defaults_set_override_orientation(gboolean bOverOrien);
+void     gtk_gs_defaults_set_watch_doc(gint iNewWatchDoc);
+void     gtk_gs_defaults_set_zoom_factor(gfloat fZoom);
+gint     gtk_gs_defaults_get_media(void);
+gboolean gtk_gs_defaults_get_override_media(void);
+gboolean gtk_gs_defaults_get_antialiased(void);
+gint     gtk_gs_defaults_get_orientation(void);
+gboolean gtk_gs_defaults_get_override_orientation(void);
+gfloat   gtk_gs_defaults_get_zoom_factor(void);
+gint     gtk_gs_defaults_get_watch_doc(void) ;
+gint     gtk_gs_defaults_get_paper_count(void);
+gboolean gtk_gs_defaults_get_respect_eof(void);
+void     gtk_gs_defaults_set_respect_eof(gboolean resp);
+GtkGSPaperSize *gtk_gs_defaults_get_paper_sizes(void);
+gint     gtk_gs_defaults_get_paper_count(void);
+const gchar *gtk_gs_defaults_get_interpreter_cmd(void);
+const gchar *gtk_gs_defaults_get_scan_pdf_cmd(void);
+const gchar *gtk_gs_defaults_get_ungzip_cmd(void);
+const gchar *gtk_gs_defaults_get_unbzip2_cmd(void);
+void gtk_gs_defaults_set_interpreter_cmd(const gchar *);
+void gtk_gs_defaults_set_scan_pdf_cmd(const gchar *);
+void gtk_gs_defaults_set_ungzip_cmd(const gchar *);
+void gtk_gs_defaults_set_unbzip2_cmd(const gchar *);
+
+/* utility functions */
+gint     gtk_gs_get_media_index(gchar *string, GtkGSPaperSize *media);
 
 #define GTK_GS_IS_COMPRESSED(gs)       (gs->gs_filename_unc != NULL)
 #define GTK_GS_GET_PS_FILE(gs)         (GTK_GS_IS_COMPRESSED(gs) ? \
