@@ -55,6 +55,7 @@
 #endif
 #include <ctype.h>
 #include <X11/Xos.h>		/* #includes the appropriate <string.h> */
+#include "gtkgs.h"
 #include "ps.h"
 
 #ifdef BSD4_2
@@ -69,25 +70,6 @@
 
 	/* list of standard paper sizes from Adobe's PPD. */
 
-struct documentmedia papersizes[PAPER_SIZE_COUNT+1] = {
-    {"BBox",	         0,  0},
-    {"Letter",		 612,  792,},
-    {"Tabloid",		 792, 1224,},
-    {"Ledger",		1224,  792,},
-    {"Legal",		 612, 1008,},
-    {"Statement",	 396,  612,},
-    {"Executive",	 540,  720,},
-    {"A3",		 842, 1190,},
-    {"A4",		 595,  842,},
-    {"A5",		 420,  595,},
-    {"B4",		 729, 1032,},
-    {"B5",		 516,  729,},
-    {"Folio",		 612,  936,},
-    {"Quarto",		 610,  780,},
-    {"10x14",		 720, 1008,},
-    {NULL,		   0,    0}
-};
-
 #if NeedFunctionPrototypes
 static char *readline(char *line, int size, FILE *fp,
 		      long *position, unsigned int *line_len);
@@ -100,7 +82,6 @@ static char *gettextline();
 static char *get_next_text();
 static int  blank();
 #endif
-static char    *skipped_line = "% ps_io_fgetchars: skipped line";
 
 
 /*
@@ -217,6 +198,7 @@ static char    *skipped_line = "% ps_io_fgetchars: skipped line";
  
 #include <glib.h>
 
+#include <gtkgs.h>
 
 struct document *psscan (FILE *file, int respect_eof)
 {
@@ -242,7 +224,8 @@ struct document *psscan (FILE *file, int respect_eof)
     unsigned int section_len;	/* Place to accumulate the section length */
     char *next_char;		/* 1st char after text returned by get_next_text() */
     char *cp;
-    struct documentmedia *dmp;
+    GtkGSPaperSize *dmp;
+    GtkGSPaperSize *papersizes = gtk_gs_defaults_get_paper_sizes();
 
     if (!file)
         return NULL;
@@ -407,7 +390,7 @@ struct document *psscan (FILE *file, int respect_eof)
 	} else if (doc->nummedia == NONE &&
 		   iscomment(line+2, "DocumentMedia:")) {
 	    float w, h;
-	    doc->media = g_new0 (struct documentmedia, 1);
+	    doc->media = g_new0 (GtkGSPaperSize, 1);
 	    doc->media[0].name = get_next_text(line+length("%%DocumentMedia:"),
 					 &next_char);
 	    if (doc->media[0].name != NULL) {
@@ -424,7 +407,7 @@ struct document *psscan (FILE *file, int respect_eof)
 	    while (readline(line, sizeof line, file, &position, &line_len) &&
 		   DSCcomment(line) && iscomment(line+2, "+")) {
 		section_len += line_len;
-		doc->media = g_renew (struct documentmedia,
+		doc->media = g_renew (GtkGSPaperSize,
 				      doc->media, doc->nummedia+1);
 		doc->media[doc->nummedia].name = get_next_text(line+length("%%+"),
 							 &next_char);
@@ -444,7 +427,7 @@ struct document *psscan (FILE *file, int respect_eof)
 	} else if (doc->nummedia == NONE &&
 		   iscomment(line+2, "DocumentPaperSizes:")) {
 
-	    doc->media = g_new0 (struct documentmedia, 1);
+	    doc->media = g_new0 (GtkGSPaperSize, 1);
 	    doc->media[0].name = get_next_text(line+length("%%DocumentPaperSizes:"),
 					 &next_char);
 	    if (doc->media[0].name != NULL) {
@@ -469,7 +452,7 @@ struct document *psscan (FILE *file, int respect_eof)
 		    g_free(doc->media[0].name);
 	    }
 	    while ( (cp = get_next_text(next_char, &next_char)) ) {
-		doc->media = g_renew (struct documentmedia,
+		doc->media = g_renew (GtkGSPaperSize,
 				      doc->media, doc->nummedia+1);
 		doc->media[doc->nummedia].name = cp;
 		doc->media[doc->nummedia].width = 0;
@@ -500,7 +483,7 @@ struct document *psscan (FILE *file, int respect_eof)
 		section_len += line_len;
 		next_char = line + length("%%+");
 		while ((cp = get_next_text(next_char, &next_char)) ) {
-		    doc->media = g_renew (struct documentmedia,
+		    doc->media = g_renew (GtkGSPaperSize,
 					  doc->media, doc->nummedia+1);
 		    doc->media[doc->nummedia].name = cp;
 		    doc->media[doc->nummedia].width = 0;
@@ -1516,7 +1499,6 @@ char *pscopyuntil(FILE *from, FILE *to, long begin, long end, const char *commen
     int comment_length;
     int i;
     char buf[BUFSIZ];
-    char *cp;
 
     if (comment != NULL)
       comment_length = strlen(comment);
